summaryrefslogtreecommitdiff
path: root/lisp/net
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/net')
-rw-r--r--lisp/net/ange-ftp.el2
-rw-r--r--lisp/net/tls.el6
-rw-r--r--lisp/net/tramp-smb.el6
-rw-r--r--lisp/net/tramp-util.el4
-rw-r--r--lisp/net/tramp-vc.el26
-rw-r--r--lisp/net/tramp.el96
6 files changed, 70 insertions, 70 deletions
diff --git a/lisp/net/ange-ftp.el b/lisp/net/ange-ftp.el
index 16a4826b8ae..8b4ed89e7b0 100644
--- a/lisp/net/ange-ftp.el
+++ b/lisp/net/ange-ftp.el
@@ -1004,7 +1004,7 @@ or nil meaning don't change it."
:type '(repeat (cons regexp (choice (const :tag "On" "on")
(const :tag "Off" "off")
(const :tag "Don't change" nil))))
- :version "21.4")
+ :version "22.1")
;;;; ------------------------------------------------------------
;;;; Hash table support.
diff --git a/lisp/net/tls.el b/lisp/net/tls.el
index 1b58760c17c..fd747387100 100644
--- a/lisp/net/tls.el
+++ b/lisp/net/tls.el
@@ -67,21 +67,21 @@ after successful negotiation."
(defcustom tls-process-connection-type nil
"*Value for `process-connection-type' to use when starting TLS process."
- :version "21.4"
+ :version "22.1"
:type 'boolean
:group 'tls)
(defcustom tls-success "- Handshake was completed"
"*Regular expression indicating completed TLS handshakes.
The default is what GNUTLS's \"gnutls-cli\" outputs."
- :version "21.4"
+ :version "22.1"
:type 'regexp
:group 'tls)
(defcustom tls-certtool-program (executable-find "certtool")
"Name of GnuTLS certtool.
Used by `tls-certificate-information'."
- :version "21.4"
+ :version "22.1"
:type '(repeat string)
:group 'tls)
diff --git a/lisp/net/tramp-smb.el b/lisp/net/tramp-smb.el
index 6fa0433a574..55ab9e693f1 100644
--- a/lisp/net/tramp-smb.el
+++ b/lisp/net/tramp-smb.el
@@ -340,11 +340,11 @@ KEEP-DATE is not handled in case NEWNAME resides on an SMB server."
(mapcar
(lambda (x)
;; We cannot call `file-attributes' for backward compatibility reasons.
- ;; Its optional parameter ID-FORMAT is introduced with Emacs 21.4.
+ ;; Its optional parameter ID-FORMAT is introduced with Emacs 22.1.
(cons x (tramp-smb-handle-file-attributes
(if full x (concat (file-name-as-directory directory) x)) id-format)))
(directory-files directory full match nosort)))
-
+
(defun tramp-smb-handle-file-attributes (filename &optional id-format)
"Like `file-attributes' for tramp files."
; (with-parsed-tramp-file-name filename nil
@@ -500,7 +500,7 @@ WILDCARD and FULL-DIRECTORY-P are not handled."
(entries (tramp-smb-get-file-entries user host share file)))
;; Delete dummy "" entry, useless entries
- (setq entries
+ (setq entries
(if (file-directory-p filename)
(delq (assoc "" entries) entries)
;; We just need the only and only entry FILENAME.
diff --git a/lisp/net/tramp-util.el b/lisp/net/tramp-util.el
index 1cd7f14dcd6..8f195fe4ad8 100644
--- a/lisp/net/tramp-util.el
+++ b/lisp/net/tramp-util.el
@@ -34,7 +34,7 @@
;; Define a Tramp minor mode. It's intention is to redefine some keys for Tramp
;; specific functions, like compilation.
-;; The key remapping works since Emacs 21.4 only. Unknown for XEmacs.
+;; The key remapping works since Emacs 22.1 only. Unknown for XEmacs.
(when (fboundp 'define-minor-mode)
@@ -59,7 +59,7 @@ If remapping functionality for keymaps is defined, this happens for all
bindings. Otherwise, only bindings active during invocation are taken
into account. XEmacs menubar bindings are not changed by this."
(if (functionp 'command-remapping)
- ;; Emacs 21.4
+ ;; Emacs 22.1
(eval
`(define-key tramp-minor-mode-map [remap ,old-command] new-command))
;; previous Emacs 21 versions.
diff --git a/lisp/net/tramp-vc.el b/lisp/net/tramp-vc.el
index c2a9ae737df..7c75b0f01c9 100644
--- a/lisp/net/tramp-vc.el
+++ b/lisp/net/tramp-vc.el
@@ -51,7 +51,7 @@
;; This used to blow away the file-name-handler-alist and reinstall
;; TRAMP into it. This was intended to let VC work remotely. It didn't,
;; at least not in my XEmacs 21.2 install.
-;;
+;;
;; In any case, tramp-run-real-handler now deals correctly with disabling
;; the things that should be, making this a no-op.
;;
@@ -96,7 +96,7 @@ See `vc-do-command' for more information."
(set (make-local-variable 'vc-parent-buffer-name)
(concat " from " (buffer-name camefrom)))
(setq default-directory olddir)
-
+
(erase-buffer)
(mapcar
@@ -230,7 +230,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(if (or (and (stringp file) (tramp-tramp-file-p file))
(and (buffer-file-name) (tramp-tramp-file-p (buffer-file-name))))
(setq ad-return-value
- (apply 'tramp-vc-do-command-new buffer okstatus command
+ (apply 'tramp-vc-do-command-new buffer okstatus command
file ;(or file (buffer-file-name))
flags))
ad-do-it)))
@@ -243,7 +243,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(if (or (and (stringp file) (tramp-tramp-file-p file))
(and (buffer-file-name) (tramp-tramp-file-p (buffer-file-name))))
(setq ad-return-value
- (apply 'tramp-vc-do-command buffer okstatus command
+ (apply 'tramp-vc-do-command buffer okstatus command
(or file (buffer-file-name)) last flags))
ad-do-it)))))
;;-)
@@ -298,7 +298,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(tramp-wait-for-output)
(setq exec-status (read (current-buffer)))
(message "Command %s returned status %d." command exec-status)))
-
+
;; Maybe okstatus can be `async' here. But then, maybe the
;; async thing is new in Emacs 21, but this function is only
;; used in Emacs 20.
@@ -319,7 +319,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
(if (or (and (stringp file) (tramp-tramp-file-p file))
(and (buffer-file-name) (tramp-tramp-file-p (buffer-file-name))))
(setq ad-return-value
- (apply 'tramp-vc-simple-command okstatus command
+ (apply 'tramp-vc-simple-command okstatus command
(or file (buffer-file-name)) args))
ad-do-it)))
@@ -381,17 +381,17 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
;; Do we need to advise the vc-user-login-name function anyway?
-;; This will return the correct login name for the owner of a
+;; This will return the correct login name for the owner of a
;; file. It does not deal with the default remote user name...
;;
-;; That is, when vc calls (vc-user-login-name), we return the
+;; That is, when vc calls (vc-user-login-name), we return the
;; local login name, something that may be different to the remote
-;; default.
+;; default.
;;
;; The remote VC operations will occur as the user that we logged
;; in with however - not always the same as the local user.
;;
-;; In the end, I did advise the function. This is because, well,
+;; In the end, I did advise the function. This is because, well,
;; the thing didn't work right otherwise ;)
;;
;; Daniel Pittman <daniel@danann.net>
@@ -409,7 +409,7 @@ filename we are thinking about..."
;; boundness-checking into this function?
(let* ((file (symbol-value 'file))
(remote-uid
- ;; With Emacs 21.4, `file-attributes' has got an optional parameter
+ ;; With Emacs 22.1, `file-attributes' has got an optional parameter
;; ID-FORMAT. Handle this case backwards compatible.
(if (and (functionp 'subr-arity)
(= 2 (cdr (funcall (symbol-function 'subr-arity)
@@ -444,11 +444,11 @@ filename we are thinking about..."
(tramp-handle-vc-user-login-name uid)))) ; get the owner name
ad-do-it))) ; else call the original
-
+
;; Determine the name of the user owning a file.
(defun tramp-file-owner (filename)
"Return who owns FILE (user name, as a string)."
- (let ((v (tramp-dissect-file-name
+ (let ((v (tramp-dissect-file-name
(expand-file-name filename))))
(if (not (file-exists-p filename))
nil ; file cannot be opened
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 90bc30744c7..583b5fa2afe 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -34,7 +34,7 @@
;;
;; Notes:
;; -----
-;;
+;;
;; This package only works for Emacs 20 and higher, and for XEmacs 21
;; and higher. (XEmacs 20 is missing the `with-timeout' macro. Emacs
;; 19 is reported to have other problems. For XEmacs 21, you need the
@@ -160,7 +160,7 @@ Nil means to use a separate filename syntax for Tramp.")
(defgroup tramp nil
"Edit remote files with a combination of rsh and rcp or similar programs."
:group 'files
- :version "21.4")
+ :version "22.1")
(defcustom tramp-verbose 9
"*Verbosity level for tramp.el. 0 means be silent, 10 is most verbose."
@@ -205,7 +205,7 @@ file name, the backup directory is prepended with Tramp file name prefix
gives the same backup policy for Tramp files on their hosts like the
policy for local files."
- :type '(repeat
+ :type '(repeat
(list (regexp :tag "File regexp")
(string :tag "Backup Dir")
(set :inline t
@@ -506,7 +506,7 @@ This variable defaults to the value of `tramp-encoding-shell'."
(tramp-copy-args nil)
(tramp-copy-keep-date-arg "-p")
(tramp-password-end-of-line "xy")) ;see docstring for "xy"
- ("fcp"
+ ("fcp"
(tramp-connection-function tramp-open-connection-rsh)
(tramp-login-program "fsh")
(tramp-copy-program "fcp")
@@ -633,7 +633,7 @@ variable `tramp-methods'."
("rsh" tramp-multi-connect-rlogin "rsh %h -l %u%n")
("remsh" tramp-multi-connect-rlogin "remsh %h -l %u%n")
("ssh" tramp-multi-connect-rlogin "ssh %h -l %u%n")
- ("ssht" tramp-multi-connect-rlogin "ssh %h -e none -t -t -l %u%n")
+ ("ssht" tramp-multi-connect-rlogin "ssh %h -e none -t -t -l %u%n")
("su" tramp-multi-connect-su "su - %u%n")
("sudo" tramp-multi-connect-su "sudo -u %u -s -p Password:%n"))
"*List of connection functions for multi-hop methods.
@@ -777,7 +777,7 @@ the info pages.")
"sudo" tramp-completion-function-alist-su)
(tramp-set-completion-function
"multi" nil)
- (tramp-set-completion-function
+ (tramp-set-completion-function
"scpx" tramp-completion-function-alist-ssh)
(tramp-set-completion-function
"sshx" tramp-completion-function-alist-ssh)
@@ -2064,7 +2064,7 @@ target of the symlink differ."
(setq filename (tramp-file-name-localname
(tramp-dissect-file-name
(expand-file-name filename)))))
-
+
;; Right, they are on the same host, regardless of user, method, etc.
;; We now make the link on the remote machine. This will occur as the user
;; that FILENAME belongs to.
@@ -2073,7 +2073,7 @@ target of the symlink differ."
l-multi-method l-method l-user l-host
(format "cd %s && %s -sf %s %s"
cwd ln
- filename
+ filename
l-localname)
t)))))
@@ -2419,7 +2419,7 @@ of."
(let* ((attr (file-attributes f))
(modtime (nth 5 attr))
(mt (visited-file-modtime)))
-
+
(cond
;; file exists, and has a known modtime.
((and attr (not (equal modtime '(0 0))))
@@ -2766,7 +2766,7 @@ if the remote host can't provide the modtime."
(push (buffer-substring (point)
(tramp-line-end-position))
result))
-
+
(tramp-send-command multi-method method user host "cd")
(tramp-wait-for-output)
@@ -3211,7 +3211,7 @@ This is like `dired-recursive-delete-directory' for tramp files."
'file-error
(list "Removing old file name" "no such directory" filename)))
;; Which is better, -r or -R? (-r works for me <daniel@danann.net>)
- (tramp-send-command multi-method method user host
+ (tramp-send-command multi-method method user host
(format "rm -r %s" (tramp-shell-quote-argument localname)))
;; Wait for the remote system to return to us...
;; This might take a while, allow it plenty of time.
@@ -3219,7 +3219,7 @@ This is like `dired-recursive-delete-directory' for tramp files."
;; Make sure that it worked...
(and (file-exists-p filename)
(error "Failed to recursively delete %s" filename))))
-
+
(defun tramp-handle-dired-call-process (program discard &rest arguments)
"Like `dired-call-process' for tramp files."
(with-parsed-tramp-file-name default-directory nil
@@ -3241,7 +3241,7 @@ This is like `dired-recursive-delete-directory' for tramp files."
(tramp-send-command-and-check multi-method method user host nil)
(tramp-send-command multi-method method user host "cd")
(tramp-wait-for-output)))))
-
+
(defun tramp-handle-dired-compress-file (file &rest ok-flag)
"Like `dired-compress-file' for tramp files."
;; OK-FLAG is valid for XEmacs only, but not implemented.
@@ -3501,7 +3501,7 @@ Used in `tramp-handle-shell-command'")
This will break if COMMAND prints a newline, followed by the value of
`tramp-end-of-output', followed by another newline."
;; Asynchronous processes are far from being perfect. But it works at least
;; for `find-grep-dired' and `find-name-dired' in Emacs 21.4.
(if (tramp-tramp-file-p default-directory)
(with-parsed-tramp-file-name default-directory nil
(let ((asynchronous (string-match "[ \t]*&[ \t]*\\'" command))
@@ -3609,7 +3609,7 @@ This will break if COMMAND prints a newline, followed by the value of
(when (and (numberp buffer) (zerop buffer))
(error "Implementation does not handle immediate return"))
(when (consp buffer) (error "Implementation does not handle error files"))
- (shell-command
+ (shell-command
(mapconcat 'tramp-shell-quote-argument
(cons program args)
" ")
@@ -4213,7 +4213,7 @@ Falls back to normal file name handler if no tramp file name handler exists."
(defun tramp-repair-jka-compr ()
"If jka-compr is already loaded, move it to the front of
-`file-name-handler-alist'. On Emacs 21.4 or so this will not be
+`file-name-handler-alist'. On Emacs 22.1 or so this will not be
necessary anymore."
(let ((jka (rassoc 'jka-compr-handler file-name-handler-alist)))
(when jka
@@ -4293,7 +4293,7 @@ necessary anymore."
;; `tramp-completion-file-name-regexp-unified' aren't different.
;; If nil, `tramp-completion-run-real-handler' is called (i.e. forwarding to
;; `tramp-file-name-handler'). Otherwise, it takes `tramp-run-real-handler'.
-;; Using `last-input-event' is a little bit risky, because completing a file
+;; Using `last-input-event' is a little bit risky, because completing a file
;; might require loading other files, like "~/.netrc", and for them it
;; shouldn't be decided based on that variable. On the other hand, those files
;; shouldn't have partial tramp file name syntax. Maybe another variable should
@@ -4397,7 +4397,7 @@ necessary anymore."
(funcall (nth 0 x) (nth 1 x)))))
(tramp-get-completion-function m))
- (setq result (append result
+ (setq result (append result
(mapcar
(lambda (x)
(tramp-get-completion-user-host
@@ -4438,7 +4438,7 @@ necessary anymore."
;; [nil nil "x" nil nil]
;; [nil "x" nil nil nil]
-;; "/x:" "/x:y" "/x:y:"
+;; "/x:" "/x:y" "/x:y:"
;; [nil nil nil "x" ""] [nil nil nil "x" "y"] [nil "x" nil "y" ""]
;; "/[x/" "/[x/y"
;; [nil "x" nil "" nil] [nil "x" nil "y" nil]
@@ -4907,7 +4907,7 @@ TIME is an Emacs internal time value as returned by `current-time'."
"touch" nil (current-buffer) nil "-t" touch-time file))
(pop-to-buffer (current-buffer))
(error "tramp-touch: touch failed"))))))
-
+
(defun tramp-buffer-name (multi-method method user host)
"A name for the connection buffer for USER at HOST using METHOD."
(if multi-method
@@ -5072,7 +5072,7 @@ file exists and nonzero exit status otherwise."
(file-exists-p existing)
(not (file-exists-p nonexisting))))
(error "Couldn't find command to check if file exists."))))
-
+
;; CCC test ksh or bash found for tilde expansion?
(defun tramp-find-shell (multi-method method user host)
@@ -5171,9 +5171,9 @@ Returns nil if none was found, else the command is returned."
(tramp-check-ls-commands multi-method method user host "gnuls" tramp-remote-path)
(tramp-check-ls-commands multi-method method user host "gls" tramp-remote-path)))
-;; ------------------------------------------------------------
-;; -- Functions for establishing connection --
-;; ------------------------------------------------------------
+;; ------------------------------------------------------------
+;; -- Functions for establishing connection --
+;; ------------------------------------------------------------
;; The following functions are actions to be taken when seeing certain
;; prompts from the remote host. See the variable
@@ -5422,7 +5422,7 @@ Maybe the different regular expressions need to be tuned.
(when multi-method
(error "Cannot multi-connect using telnet connection method"))
(tramp-pre-connection multi-method method user host)
- (tramp-message 7 "Opening connection for %s@%s using %s..."
+ (tramp-message 7 "Opening connection for %s@%s using %s..."
(or user (user-login-name)) host method)
(let ((process-environment (copy-sequence process-environment)))
(setenv "TERM" tramp-terminal-type)
@@ -5456,7 +5456,7 @@ Maybe the different regular expressions need to be tuned.
p multi-method method user host)
(tramp-post-connection multi-method method user host)))))
-
+
(defun tramp-open-connection-rsh (multi-method method user host)
"Open a connection using an rsh METHOD.
This starts the command `rsh HOST -l USER'[*], then waits for a remote
@@ -5481,7 +5481,7 @@ arguments, and xx will be used as the host name to connect to.
(error "Cannot multi-connect using rsh connection method"))
(tramp-pre-connection multi-method method user host)
(if (and user (not (string= user "")))
- (tramp-message 7 "Opening connection for %s@%s using %s..."
+ (tramp-message 7 "Opening connection for %s@%s using %s..."
user host method)
(tramp-message 7 "Opening connection at %s using %s..." host method))
(let ((process-environment (copy-sequence process-environment))
@@ -5510,9 +5510,9 @@ arguments, and xx will be used as the host name to connect to.
(> emacs-major-version 20))
tramp-dos-coding-system))
(p (if (and user (not (string= user "")))
- (apply #'start-process bufnam buf login-program
+ (apply #'start-process bufnam buf login-program
real-host "-l" user login-args)
- (apply #'start-process bufnam buf login-program
+ (apply #'start-process bufnam buf login-program
real-host login-args)))
(found nil))
(tramp-set-process-query-on-exit-flag p nil)
@@ -5582,10 +5582,10 @@ prompt than you do, so it is not at all unlikely that the variable
tramp-actions-before-shell)
(tramp-open-connection-setup-interactive-shell
p multi-method method user host)
- (tramp-post-connection multi-method method
+ (tramp-post-connection multi-method method
user host)))))
-;; HHH: Not Changed. Multi method. It is not clear to me how this can
+;; HHH: Not Changed. Multi method. It is not clear to me how this can
;; handle not giving a user name in the "file name".
;;
;; This is more difficult than for the single-hop method. In the
@@ -5655,7 +5655,7 @@ log in as u2 to h2."
(tramp-post-connection multi-method method user host)))))
;; HHH: Changed. Multi method. Don't know how to handle this in the case
-;; of no user name provided. Hack to make it work as it did before:
+;; of no user name provided. Hack to make it work as it did before:
;; changed `user' to `(or user (user-login-name))' in the places where
;; the value is actually used.
(defun tramp-multi-connect-telnet (p method user host command)
@@ -5677,8 +5677,8 @@ If USER is nil, uses the return value of (user-login-name) instead."
(tramp-process-multi-actions p method user host
tramp-multi-actions)))
-;; HHH: Changed. Multi method. Don't know how to handle this in the case
-;; of no user name provided. Hack to make it work as it did before:
+;; HHH: Changed. Multi method. Don't know how to handle this in the case
+;; of no user name provided. Hack to make it work as it did before:
;; changed `user' to `(or user (user-login-name))' in the places where
;; the value is actually used.
(defun tramp-multi-connect-rlogin (p method user host command)
@@ -5703,8 +5703,8 @@ If USER is nil, uses the return value of (user-login-name) instead."
(tramp-process-multi-actions p method user host
tramp-multi-actions)))
-;; HHH: Changed. Multi method. Don't know how to handle this in the case
-;; of no user name provided. Hack to make it work as it did before:
+;; HHH: Changed. Multi method. Don't know how to handle this in the case
+;; of no user name provided. Hack to make it work as it did before:
;; changed `user' to `(or user (user-login-name))' in the places where
;; the value is actually used.
(defun tramp-multi-connect-su (p method user host command)
@@ -6334,7 +6334,7 @@ Sends COMMAND, then waits 30 seconds for shell prompt."
(tramp-barf-if-no-shell-prompt
nil 30
"Couldn't `%s', see buffer `%s'" command (buffer-name)))
-
+
(defun tramp-wait-for-output (&optional timeout)
"Wait for output from remote rsh command."
(let ((proc (get-buffer-process (current-buffer)))
@@ -6667,9 +6667,9 @@ Not actually used. Use `(format \"%o\" i)' instead?"
""))
-;; ------------------------------------------------------------
-;; -- TRAMP file names --
-;; ------------------------------------------------------------
+;; ------------------------------------------------------------
+;; -- TRAMP file names --
+;; ------------------------------------------------------------
;; Conversion functions between external representation and
;; internal data structure. Convenience functions for internal
;; data structure.
@@ -6680,7 +6680,7 @@ Not actually used. Use `(format \"%o\" i)' instead?"
"Return t iff NAME is a tramp file."
(save-match-data
(string-match tramp-file-name-regexp name)))
-
+
;; HHH: Changed. Used to assign the return value of (user-login-name)
;; to the `user' part of the structure if a user name was not
;; provided, now it assigns nil.
@@ -6733,7 +6733,7 @@ This is MULTI-METHOD, if non-nil. Otherwise, it is METHOD, if non-nil.
If both MULTI-METHOD and METHOD are nil, do a lookup in
`tramp-default-method-alist'."
(or multi-method method (tramp-find-default-method user host)))
-
+
;; HHH: Not Changed. Multi method. Will probably not handle the case where
;; a user name is not provided in the "file name" very well.
(defun tramp-dissect-multi-file-name (name)
@@ -6905,7 +6905,7 @@ as default."
(if entry
(second entry)
(symbol-value param))))
-
+
;; Auto saving to a special directory.
@@ -6937,7 +6937,7 @@ as default."
(tramp-make-auto-save-file-name (buffer-file-name)))
ad-do-it))
;; In Emacs < 21.4 and XEmacs < 21.5 autosaved remote files have
;; permission 666 minus umask. This is a security threat.
(defun tramp-set-auto-save-file-modes ()
@@ -7097,9 +7097,9 @@ exiting if process is running."
process flag)))
-;; ------------------------------------------------------------
-;; -- Kludges section --
-;; ------------------------------------------------------------
+;; ------------------------------------------------------------
+;; -- Kludges section --
+;; ------------------------------------------------------------
;; Currently (as of Emacs 20.5), the function `shell-quote-argument'
;; does not deal well with newline characters. Newline is replaced by
@@ -7362,7 +7362,7 @@ report.
;; strange when doing zerop, we should kill the process and start
;; again. (Greg Stark)
;; * Add caching for filename completion. (Greg Stark)
-;; Of course, this has issues with usability (stale cache bites)
+;; Of course, this has issues with usability (stale cache bites)
;; -- <daniel@danann.net>
;; * Provide a local cache of old versions of remote files for the rsync
;; transfer method to use. (Greg Stark)
@@ -3501,7 +3501,7 @@ Used in `tramp-handle-shell-command'")
`tramp-end-of-output', followed by another newline."
;; Asynchronous processes are far from being perfect. But it works at least
- ;; for `find-grep-dired' and `find-name-dired' in Emacs 21.4.
+ ;; for `find-grep-dired' and `find-name-dired' in Emacs 22.1.
(if (tramp-tramp-file-p default-directory)
(with-parsed-tramp-file-name default-directory nil
@@ -6937,7 +6937,7 @@ as default."
(tramp-make-auto-save-file-name (buffer-file-name)))
ad-do-it))
-;; In Emacs < 21.4 and XEmacs < 21.5 autosaved remote files have
+;; In Emacs < 22.1 and XEmacs < 21.5 autosaved remote files have
;; permission 666 minus umask. This is a security threat.
(defun tramp-set-auto-save-file-modes ()